@@ -36,12 +36,8 @@ extract `(cd $TARGET/var/cache/apt/archives && \
 	for i in *.deb; do dpkg-deb --field $i Priority | grep ^required \
 	&& echo $i; done) | cut -d _ -f 1`
 
-if [ -e $TARGET/var/cache/apt/archives/gnumach-image-1.5-486_* ] ; then
-        extract gnumach-image-1.5-486
-fi
-
-if [ -e $TARGET/var/cache/apt/archives/libpthread-stubs0_* ] ; then
-        extract libpthread-stubs0
+if [ -e $TARGET/var/cache/apt/archives/gnumach-image-1.6-486_* ] ; then
+        extract gnumach-image-1.6-486
 fi
 
 if [ -e $TARGET/var/cache/apt/archives/libbz2-1.0_* ] ; then
